@@ -17,13 +17,21 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
 #include <unistd.h>
 #include <string.h>
 #include <signal.h>
+#ifdef HAVE_SYSEXITS_H
 #include <sysexits.h>
+#else
+#define EX_OK     0 /* successful termination */
+#define EX_OSERR 71 /* system error (e.g., can't fork) */
+#define EX_USAGE 64 /* command line usage error */
+#endif
 #include <sys/time.h>
 #include <pthread.h>
 #include <stdbool.h>
@@ -35,10 +43,6 @@
 #include <winscard.h>
 #endif
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #define TIMEOUT 3600*1000	/* 1 hour timeout */
 
 
@@ -54,7 +58,7 @@ const char *pcsc_stringify_error(DWORD rv)
 	if (! FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM,
 		NULL,
 		rv,
-		MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // default language
+		LANG_USER_DEFAULT,
 		buffer,
 		sizeof buffer,
 		NULL))
@@ -86,9 +90,7 @@ static void usage(const char *pname)
 	printf("%s usage:\n\n\t%s [ -h | -V | -n | -r | -c | -s | -t secs | -d | -p]\n\n", pname, pname);
 	printf("\t\t  -h : this help\n");
 	printf("\t\t  -V : print version number\n");
-#ifndef WIN32
 	printf("\t\t  -n : no ATR analysis\n");
-#endif
 	printf("\t\t  -r : only lists readers\n");
 	printf("\t\t  -c : only lists cards\n");
 	printf("\t\t  -s : stress mode\n");
@@ -108,6 +110,7 @@ const char *color_end = "";
 const char *cub2 = "";
 const char *cub3 = "";
 const char *cpl = "";
+const char *cnl = "";
 
 time_t start_time;
 _Atomic bool Interrupted = false;
@@ -165,6 +168,7 @@ static void initialize_terminal(void)
 		cub2 = "\r"; /* use carriage return */
 		cub3 = "\r";
 		cpl = "\n"; /* can't do previous line,  let's go to the next line. */
+		cnl = "\n";
 	}
 	else
 	{
@@ -184,11 +188,6 @@ static bool should_exit(void)
 			return true;
 	}
 
-#ifdef WIN32
-	if (GetKeyState(VK_SHIFT) & 0x80)
-		return true;
-#endif
-
 	if (Interrupted)
 		return true;
 
@@ -207,6 +206,7 @@ _Atomic SpinState_t spin_state = SpinStopped;
 static void spin_start(void)
 {
 	spin_state = Options.verbose ? SpinRunning : SpinDisabled;
+	printf("%s", cnl);
 }
 
 static void spin_stop(void)
@@ -298,12 +298,7 @@ static void initialize_options(options_t *options, const char *pname)
 	options->maxtime = 0;
 }
 
-#define OPTIONS_BASE "Vhvrcst:qdp"
-#ifdef WIN32
-#define OPTIONS OPTIONS_BASE
-#else
-#define OPTIONS OPTIONS_BASE "n"
-#endif
+#define OPTIONS "Vhvrcst:qdpn"
 
 static void print_version(void)
 {
@@ -531,7 +526,7 @@ int main(int argc, char *argv[])
 	LONG rv;
 #endif
 	SCARD_READERSTATE *rgReaderStates_t = NULL;
-	SCARD_READERSTATE rgReaderStates[1];
+	SCARD_READERSTATE rgReaderStates[1] = { 0, };
 	DWORD dwReaders = 0, dwReadersOld;
 	LPSTR mszReaders = NULL;
 	char *ptr = NULL;
@@ -552,14 +547,7 @@ int main(int argc, char *argv[])
 		print_version();
 	}
 
-#ifdef WIN32
-	if (Options.verbose)
-	{
-		printf("%sPress shift key to quit%s\n", magenta, color_end);
-	}
-#else
 	initialize_signal_handlers();
-#endif
 
 	rv = SCardEstablishContext(SCARD_SCOPE_SYSTEM, NULL, NULL, &hContext);
 	test_rv("SCardEstablishContext", rv, hContext);
